@@ -49,7 +49,8 @@
     (define-key map "u" 'tree-mode-goto-parent)
     (define-key map "r" 'tree-mode-goto-root)
     (define-key map "g" 'tree-mode-reflesh)
-    (define-key map "e" 'tree-mode-expand-level)
+    (define-key map "E" 'tree-mode-expand-level)
+    (define-key map "e" 'tree-mode-toggle-expand)
     (define-key map "s" 'tree-mode-sort-by-tag)
     (define-key map "/" 'tree-mode-keep-match)
     (define-key map "!" 'tree-mode-collapse-other-except)
@@ -362,6 +363,20 @@ Note if the tree is not opened, It will open some node when need.
               (widget-apply-action child)))
         (widget-get tree :children)))
 
+(defun tree-mode-toggle-expand (arg)
+  (interactive "P")
+  (let ((me (tree-mode-icon-current-line))
+        expandp open)
+    (if (tree-widget-leaf-node-icon-p me)
+        (message "Not a tree under point!")
+      (setq me (widget-get me :parent))
+      (setq expandp (widget-get me :open))
+      (setq open (if (null arg)
+                     (not expandp)
+                   (> (prefix-numeric-value arg) 0)))
+      (unless (eq open expandp)
+        (widget-apply-action me)))))
+
 (defun tree-mode-expand-level (level)
   "Expand tree to LEVEL. With prefix argument 0 or negative, will
 expand all leaves of the tree."
